@@ -77,10 +77,15 @@ import aws_cdk.aws_elasticloadbalancingv2 as elbv2
 origin = origins.LoadBalancerV2Origin(load_balancer,
     connection_attempts=3,
     connection_timeout=Duration.seconds(5),
+    read_timeout=Duration.seconds(45),
     protocol_policy=cloudfront.OriginProtocolPolicy.MATCH_VIEWER
 )
 ```
 
+Note that the `readTimeout` property can extend its value over 60 seconds only if a limit increase request for CloudFront origin response timeout
+quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Consider that this value is
+still limited to a maximum value of 180 seconds, which is a hard limit for that quota.
+
 ## From an HTTP endpoint
 
 Origins can also be created from any other HTTP endpoint, given the domain name, and optionally, other origin properties.
@@ -180,7 +185,7 @@ class HttpOrigin(
         :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(5)
         :param origin_ssl_protocols: The SSL versions to use when interacting with the origin. Default: OriginSslPolicy.TLS_V1_2
         :param protocol_policy: Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
-        :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(30)
+        :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(30)
         :param connection_attempts: The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
         :param connection_timeout: The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
         :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
@@ -255,7 +260,7 @@ class HttpOriginProps(aws_cdk.aws_cloudfront.OriginProps):
         :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(5)
         :param origin_ssl_protocols: The SSL versions to use when interacting with the origin. Default: OriginSslPolicy.TLS_V1_2
         :param protocol_policy: Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
-        :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(30)
+        :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(30)
 
         :exampleMetadata: fixture=_generated
 
@@ -417,7 +422,10 @@ class HttpOriginProps(aws_cdk.aws_cloudfront.OriginProps):
     def read_timeout(self) -> typing.Optional[aws_cdk.core.Duration]:
         '''Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout.
 
-        The valid range is from 1 to 60 seconds, inclusive.
+        The valid range is from 1 to 180 seconds, inclusive.
+
+        Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota
+        has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time.
 
         :default: Duration.seconds(30)
         '''
@@ -447,7 +455,9 @@ class LoadBalancerV2Origin(
 
     Example::
 
-        # Creates a distribution from an ELBv2 load balancer
+        import aws_cdk.aws_ec2 as ec2
+        import aws_cdk.aws_elasticloadbalancingv2 as elbv2
+        
         # vpc: ec2.Vpc
         
         # Create an application load balancer in a VPC. 'internetFacing' must be 'true'
@@ -484,7 +494,7 @@ class LoadBalancerV2Origin(
         :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(5)
         :param origin_ssl_protocols: The SSL versions to use when interacting with the origin. Default: OriginSslPolicy.TLS_V1_2
         :param protocol_policy: Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
-        :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(30)
+        :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(30)
         :param connection_attempts: The number of times that CloudFront attempts to connect to the origin; valid values are 1, 2, or 3 attempts. Default: 3
         :param connection_timeout: The number of seconds that CloudFront waits when trying to establish a connection to the origin. Valid values are 1-10 seconds, inclusive. Default: Duration.seconds(10)
         :param custom_headers: A list of HTTP header names and values that CloudFront adds to requests it sends to the origin. Default: {}
@@ -553,7 +563,7 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
         :param keepalive_timeout: Specifies how long, in seconds, CloudFront persists its connection to the origin. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(5)
         :param origin_ssl_protocols: The SSL versions to use when interacting with the origin. Default: OriginSslPolicy.TLS_V1_2
         :param protocol_policy: Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Default: OriginProtocolPolicy.HTTPS_ONLY
-        :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 60 seconds, inclusive. Default: Duration.seconds(30)
+        :param read_timeout: Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout. The valid range is from 1 to 180 seconds, inclusive. Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time. Default: Duration.seconds(30)
 
         :exampleMetadata: infused
 
@@ -566,6 +576,7 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
             origin = origins.LoadBalancerV2Origin(load_balancer,
                 connection_attempts=3,
                 connection_timeout=Duration.seconds(5),
+                read_timeout=Duration.seconds(45),
                 protocol_policy=cloudfront.OriginProtocolPolicy.MATCH_VIEWER
             )
         '''
@@ -703,7 +714,10 @@ class LoadBalancerV2OriginProps(HttpOriginProps):
     def read_timeout(self) -> typing.Optional[aws_cdk.core.Duration]:
         '''Specifies how long, in seconds, CloudFront waits for a response from the origin, also known as the origin response timeout.
 
-        The valid range is from 1 to 60 seconds, inclusive.
+        The valid range is from 1 to 180 seconds, inclusive.
+
+        Note that values over 60 seconds are possible only after a limit increase request for the origin response timeout quota
+        has been approved in the target account; otherwise, values over 60 seconds will produce an error at deploy time.
 
         :default: Duration.seconds(30)
         '''
